@@ -69,9 +69,9 @@ Game::~Game()
 bool Game::start(const QString &command)
 {
     stop();                                   // Close old session if there's one
-    m_process.start(command.toLatin1());      // Start new process with provided command
+    m_process.start(command);      // Start new process with provided command
     if (!m_process.waitForStarted()) {        // Blocking wait for process start
-        m_response = "Unable to execute command: " + command;
+        m_response = QStringLiteral("Unable to execute command: ") + command;
         //qDebug() << m_response;
         return false;
     }
@@ -83,7 +83,7 @@ bool Game::start(const QString &command)
     m_process.waitForReadyRead();
     const QString response = m_process.readAllStandardOutput();
     if (response.isEmpty() || !response.startsWith(QLatin1String("="))) {
-        m_response = QLatin1String("Game did not respond to GTP command \"name\"");
+        m_response = QStringLiteral("Game did not respond to GTP command \"name\"");
         //qDebug() << m_response;
         stop();
         return false;
@@ -520,7 +520,7 @@ int Game::moveCount()
 
     m_process.write("move_history\n");          // Query fixed handicap and store it
     if (waitResponse()) {
-        return m_response.count('\n') + 1;
+        return m_response.count(QLatin1Char('\n')) + 1;
     }
     return 0;
 }
@@ -536,7 +536,7 @@ QList<Stone> Game::stones(const Player &player)
     if (!player.isWhite()) {
         m_process.write("list_stones black\n");
         if (waitResponse() && !m_response.isEmpty()) {
-            foreach (const QString &pos, m_response.split(' ')) {
+            foreach (const QString &pos, m_response.split(QLatin1Char(' '))) {
                 list.append(Stone(pos));
             }
         }
@@ -544,7 +544,7 @@ QList<Stone> Game::stones(const Player &player)
     if (!player.isBlack()) {
         m_process.write("list_stones white\n");
         if (waitResponse() && !m_response.isEmpty()) {
-            foreach (const QString &pos, m_response.split(' ')) {
+            foreach (const QString &pos, m_response.split(QLatin1Char(' '))) {
                 list.append(Stone(pos));
             }
         }
@@ -580,7 +580,7 @@ QList<Stone> Game::liberties(const Stone &stone)
 
     m_process.write("findlib " + stone.toLatin1() + '\n');
     if (waitResponse() && !m_response.isEmpty()) {
-        foreach (const QString &entry, m_response.split(' ')) {
+        foreach (const QString &entry, m_response.split(QLatin1Char(' '))) {
             list.append(Stone(entry));
         }
     }
@@ -600,7 +600,7 @@ QList<Stone> Game::bestMoves(const Player &player)
         m_process.write("top_moves_black\n");
     }
     if (waitResponse(true) && !m_response.isEmpty()) {
-        const QStringList parts = m_response.split(' ');
+        const QStringList parts = m_response.split(QLatin1Char(' '));
         if (parts.size() % 2 == 0) {
             for (int i = 0; i < parts.size(); i += 2) {
                 list.append(Stone(parts[i], QString(parts[i + 1]).toFloat()));
@@ -623,7 +623,7 @@ QList<Stone> Game::legalMoves(const Player &player)
         m_process.write("all_legal black\n");
     }
     if (waitResponse() && !m_response.isEmpty()) {
-        foreach (const QString &entry, m_response.split(' ')) {
+        foreach (const QString &entry, m_response.split(QLatin1Char(' '))) {
             list.append(Stone(entry));
         }
     }
@@ -684,7 +684,7 @@ QList<Stone> Game::finalStates(FinalState state)
     msg.append('\n');
     m_process.write(msg);
     if (waitResponse() && !m_response.isEmpty()) {
-        foreach (const QString &entry, m_response.split(' ')) {
+        foreach (const QString &entry, m_response.split(QLatin1Char(' '))) {
             list.append(Stone(entry));
         }
     }
@@ -715,12 +715,12 @@ bool Game::waitResponse(bool nonBlocking)
 {
     if (m_process.state() != QProcess::Running) {   // No GTP connection means no computing fun!
         switch (m_process.error()) {
-            case QProcess::FailedToStart: m_response = QLatin1String("No Go game is running!"); break;
-            case QProcess::Crashed: m_response = QLatin1String("The Go game crashed!"); break;
-            case QProcess::Timedout: m_response = QLatin1String("The Go game timed out!"); break;
+            case QProcess::FailedToStart: m_response = QStringLiteral("No Go game is running!"); break;
+            case QProcess::Crashed: m_response = QStringLiteral("The Go game crashed!"); break;
+            case QProcess::Timedout: m_response = QStringLiteral("The Go game timed out!"); break;
             case QProcess::WriteError: m_response = m_process.readAllStandardError(); break;
             case QProcess::ReadError: m_response = m_process.readAllStandardError(); break;
-            case QProcess::UnknownError: m_response = QLatin1String("Unknown error!"); break;
+            case QProcess::UnknownError: m_response = QStringLiteral("Unknown error!"); break;
         }
         qWarning() << "Command failed:" << m_response;
         return false;
@@ -761,7 +761,7 @@ bool Game::waitResponse(bool nonBlocking)
     QChar tmp = m_response[0];                  // First message character indicates success or error
     m_response.remove(0, 2);                    // Remove the first two chars (e.g. "? " or "= ")
     m_response = m_response.trimmed();          // Remove further whitespaces, newlines, ...
-    return tmp != '?';                          // '?' Means the game didn't understand the query
+    return tmp != QLatin1Char('?');                          // '?' Means the game didn't understand the query
 }
 
 void Game::gameSetup()
